@@ -1,7 +1,6 @@
 use super::*;
 
 use async_trait::async_trait;
-use std::io;
 use std::net::{IpAddr, Ipv4Addr};
 use std::str::FromStr;
 use std::sync::atomic::AtomicU64;
@@ -13,22 +12,22 @@ pub(crate) struct MockConn;
 
 #[async_trait]
 impl Conn for MockConn {
-    async fn connect(&self, _addr: SocketAddr) -> io::Result<()> {
+    async fn connect(&self, _addr: SocketAddr) -> Result<()> {
         Ok(())
     }
-    async fn recv(&self, _buf: &mut [u8]) -> io::Result<usize> {
+    async fn recv(&self, _buf: &mut [u8]) -> Result<usize> {
         Ok(0)
     }
-    async fn recv_from(&self, _buf: &mut [u8]) -> io::Result<(usize, SocketAddr)> {
+    async fn recv_from(&self, _buf: &mut [u8]) -> Result<(usize, SocketAddr)> {
         Ok((0, SocketAddr::new(Ipv4Addr::new(0, 0, 0, 0).into(), 0)))
     }
-    async fn send(&self, _buf: &[u8]) -> io::Result<usize> {
+    async fn send(&self, _buf: &[u8]) -> Result<usize> {
         Ok(0)
     }
-    async fn send_to(&self, _buf: &[u8], _target: SocketAddr) -> io::Result<usize> {
+    async fn send_to(&self, _buf: &[u8], _target: SocketAddr) -> Result<usize> {
         Ok(0)
     }
-    async fn local_addr(&self) -> io::Result<SocketAddr> {
+    async fn local_addr(&self) -> Result<SocketAddr> {
         Ok(SocketAddr::new(Ipv4Addr::new(0, 0, 0, 0).into(), 0))
     }
 }
@@ -41,7 +40,7 @@ pub(crate) struct VNet {
 }
 
 impl VNet {
-    pub(crate) async fn close(&self) -> Result<(), Error> {
+    pub(crate) async fn close(&self) -> Result<()> {
         self.server.close()?;
         let mut w = self.wan.lock().await;
         w.stop().await?;
@@ -61,7 +60,7 @@ pub(crate) const VNET_STUN_SERVER_PORT: u16 = 3478;
 pub(crate) async fn build_simple_vnet(
     _nat_type0: nat::NatType,
     _nat_type1: nat::NatType,
-) -> Result<VNet, Error> {
+) -> Result<VNet> {
     // WAN
     let wan = Arc::new(Mutex::new(router::Router::new(router::RouterConfig {
         cidr: "0.0.0.0/0".to_owned(),
@@ -107,10 +106,7 @@ pub(crate) async fn build_simple_vnet(
     })
 }
 
-pub(crate) async fn build_vnet(
-    nat_type0: nat::NatType,
-    nat_type1: nat::NatType,
-) -> Result<VNet, Error> {
+pub(crate) async fn build_vnet(nat_type0: nat::NatType, nat_type1: nat::NatType) -> Result<VNet> {
     // WAN
     let wan = Arc::new(Mutex::new(router::Router::new(router::RouterConfig {
         cidr: "0.0.0.0/0".to_owned(),
@@ -194,21 +190,16 @@ impl TestAuthHandler {
 }
 
 impl turn::auth::AuthHandler for TestAuthHandler {
-    fn auth_handle(
-        &self,
-        username: &str,
-        _realm: &str,
-        _src_addr: SocketAddr,
-    ) -> Result<Vec<u8>, Error> {
+    fn auth_handle(&self, username: &str, _realm: &str, _src_addr: SocketAddr) -> Result<Vec<u8>> {
         if let Some(pw) = self.cred_map.get(username) {
             Ok(pw.to_vec())
         } else {
-            Err(Error::new("fake error".to_owned()))
+            Err(Error::ErrOthers("fake error".to_owned()).into())
         }
     }
 }
 
-pub(crate) async fn add_vnet_stun(wan_net: Arc<net::Net>) -> Result<turn::server::Server, Error> {
+pub(crate) async fn add_vnet_stun(wan_net: Arc<net::Net>) -> Result<turn::server::Server> {
     // Run TURN(STUN) server
     let conn = wan_net
         .bind(SocketAddr::from_str(&format!(
@@ -240,7 +231,7 @@ pub(crate) async fn add_vnet_stun(wan_net: Arc<net::Net>) -> Result<turn::server
 pub(crate) async fn connect_with_vnet(
     a_agent: &Arc<Agent>,
     b_agent: &Arc<Agent>,
-) -> Result<(Arc<impl Conn>, Arc<impl Conn>), Error> {
+) -> Result<(Arc<impl Conn>, Arc<impl Conn>)> {
     // Manual signaling
     let (a_ufrag, a_pwd) = a_agent.get_local_user_credentials().await;
     let (b_ufrag, b_pwd) = b_agent.get_local_user_credentials().await;
@@ -256,7 +247,7 @@ pub(crate) async fn connect_with_vnet(
 
         let _ = accepted_tx.send(a_conn).await;
 
-        Ok::<(), Error>(())
+        Result::<()>::Ok(())
     });
 
     let (_b_cancel_tx, b_cancel_rx) = mpsc::channel(1);
@@ -266,7 +257,7 @@ pub(crate) async fn connect_with_vnet(
     if let Some(a_conn) = accepted_rx.recv().await {
         Ok((a_conn, b_conn))
     } else {
-        Err(Error::new("no a_conn".to_owned()))
+        Err(Error::ErrOthers("no a_conn".to_owned()).into())
     }
 }
 
@@ -280,7 +271,7 @@ pub(crate) async fn pipe_with_vnet(
     v: &VNet,
     a0test_config: AgentTestConfig,
     a1test_config: AgentTestConfig,
-) -> Result<(Arc<impl Conn>, Arc<impl Conn>), Error> {
+) -> Result<(Arc<impl Conn>, Arc<impl Conn>)> {
     let (a_notifier, mut a_connected) = on_connected();
     let (b_notifier, mut b_connected) = on_connected();
 
@@ -349,7 +340,7 @@ pub(crate) fn on_connected() -> (OnConnectionStateChangeHdlrFn, mpsc::Receiver<(
 pub(crate) async fn gather_and_exchange_candidates(
     a_agent: &Arc<Agent>,
     b_agent: &Arc<Agent>,
-) -> Result<(), Error> {
+) -> Result<()> {
     let wg = WaitGroup::new();
 
     let w1 = Arc::new(Mutex::new(Some(wg.worker())));
@@ -403,7 +394,7 @@ pub(crate) async fn gather_and_exchange_candidates(
     Ok(())
 }
 
-pub(crate) async fn start_router(router: &Arc<Mutex<router::Router>>) -> Result<(), Error> {
+pub(crate) async fn start_router(router: &Arc<Mutex<router::Router>>) -> Result<()> {
     let mut w = router.lock().await;
     w.start().await
 }
@@ -411,7 +402,7 @@ pub(crate) async fn start_router(router: &Arc<Mutex<router::Router>>) -> Result<
 pub(crate) async fn connect_net2router(
     net: &Arc<net::Net>,
     router: &Arc<Mutex<router::Router>>,
-) -> Result<(), Error> {
+) -> Result<()> {
     let nic = net.get_nic()?;
 
     {
@@ -429,7 +420,7 @@ pub(crate) async fn connect_net2router(
 pub(crate) async fn connect_router2router(
     child: &Arc<Mutex<router::Router>>,
     parent: &Arc<Mutex<router::Router>>,
-) -> Result<(), Error> {
+) -> Result<()> {
     {
         let mut w = parent.lock().await;
         w.add_router(Arc::clone(child)).await?;
@@ -444,7 +435,7 @@ pub(crate) async fn connect_router2router(
 }
 
 #[tokio::test]
-async fn test_connectivity_simple_vnet_full_cone_nats_on_both_ends() -> Result<(), Error> {
+async fn test_connectivity_simple_vnet_full_cone_nats_on_both_ends() -> Result<()> {
     /*env_logger::Builder::new()
     .format(|buf, record| {
         writeln!(
@@ -497,7 +488,7 @@ async fn test_connectivity_simple_vnet_full_cone_nats_on_both_ends() -> Result<(
 }
 
 #[tokio::test]
-async fn test_connectivity_vnet_full_cone_nats_on_both_ends() -> Result<(), Error> {
+async fn test_connectivity_vnet_full_cone_nats_on_both_ends() -> Result<()> {
     /*env_logger::Builder::new()
     .format(|buf, record| {
         writeln!(
@@ -559,7 +550,7 @@ async fn test_connectivity_vnet_full_cone_nats_on_both_ends() -> Result<(), Erro
 }
 
 #[tokio::test]
-async fn test_connectivity_vnet_symmetric_nats_on_both_ends() -> Result<(), Error> {
+async fn test_connectivity_vnet_symmetric_nats_on_both_ends() -> Result<()> {
     /*env_logger::Builder::new()
     .format(|buf, record| {
         writeln!(
@@ -621,8 +612,7 @@ async fn test_connectivity_vnet_symmetric_nats_on_both_ends() -> Result<(), Erro
 }
 
 #[tokio::test]
-async fn test_connectivity_vnet_1to1_nat_with_host_candidate_vs_symmetric_nats() -> Result<(), Error>
-{
+async fn test_connectivity_vnet_1to1_nat_with_host_candidate_vs_symmetric_nats() -> Result<()> {
     /*env_logger::Builder::new()
     .format(|buf, record| {
         writeln!(
@@ -674,8 +664,7 @@ async fn test_connectivity_vnet_1to1_nat_with_host_candidate_vs_symmetric_nats()
 }
 
 #[tokio::test]
-async fn test_connectivity_vnet_1to1_nat_with_srflx_candidate_vs_symmetric_nats(
-) -> Result<(), Error> {
+async fn test_connectivity_vnet_1to1_nat_with_srflx_candidate_vs_symmetric_nats() -> Result<()> {
     /*env_logger::Builder::new()
     .format(|buf, record| {
         writeln!(
@@ -739,7 +728,7 @@ async fn block_until_state_seen(
 
 // test_disconnected_to_connected asserts that an agent can go to disconnected, and then return to connected successfully
 #[tokio::test]
-async fn test_disconnected_to_connected() -> Result<(), Error> {
+async fn test_disconnected_to_connected() -> Result<()> {
     /*env_logger::Builder::new()
     .format(|buf, record| {
         writeln!(
@@ -883,7 +872,7 @@ async fn test_disconnected_to_connected() -> Result<(), Error> {
 
 // Agent.Write should use the best valid pair if a selected pair is not yet available
 #[tokio::test]
-async fn test_write_use_valid_pair() -> Result<(), Error> {
+async fn test_write_use_valid_pair() -> Result<()> {
     /*env_logger::Builder::new()
     .format(|buf, record| {
         writeln!(
@@ -983,7 +972,7 @@ async fn test_write_use_valid_pair() -> Result<(), Error> {
             tokio::time::sleep(Duration::from_millis(20)).await;
         }
 
-        Ok::<(), Error>(())
+        Result::<()>::Ok(())
     });
 
     let controlled_agent_conn = {
