@@ -2,15 +2,15 @@
 mod util_test;
 
 use crate::agent::agent_config::InterfaceFilterFn;
-use crate::errors::*;
+use crate::error::*;
 use crate::network_type::*;
 
+use anyhow::Result;
 use std::net::{IpAddr, SocketAddr};
-use stun::{agent::*, attributes::*, integrity::*, message::*, textattrs::*, xoraddr::*};
-
 use std::sync::Arc;
+use stun::{agent::*, attributes::*, integrity::*, message::*, textattrs::*, xoraddr::*};
 use tokio::time::Duration;
-use util::{vnet::net::*, Conn, Error};
+use util::{vnet::net::*, Conn};
 
 pub fn create_addr(_network: NetworkType, ip: IpAddr, port: u16) -> SocketAddr {
     /*if network.is_tcp(){
@@ -21,23 +21,24 @@ pub fn create_addr(_network: NetworkType, ip: IpAddr, port: u16) -> SocketAddr {
     SocketAddr::new(ip, port)
 }
 
-pub fn assert_inbound_username(m: &Message, expected_username: &str) -> Result<(), Error> {
+pub fn assert_inbound_username(m: &Message, expected_username: &str) -> Result<()> {
     let mut username = Username::new(ATTR_USERNAME, String::new());
     username.get_from(m)?;
 
     if username.to_string() != expected_username {
-        return Err(Error::new(format!(
-            "{} expected({}) actual({})",
-            ERR_MISMATCH_USERNAME.to_owned(),
+        return Err(Error::ErrOthers(format!(
+            "{:?} expected({}) actual({})",
+            Error::ErrMismatchUsername,
             expected_username,
             username,
-        )));
+        ))
+        .into());
     }
 
     Ok(())
 }
 
-pub fn assert_inbound_message_integrity(m: &mut Message, key: &[u8]) -> Result<(), Error> {
+pub fn assert_inbound_message_integrity(m: &mut Message, key: &[u8]) -> Result<()> {
     let message_integrity_attr = MessageIntegrity(key.to_vec());
     message_integrity_attr.check(m)
 }
@@ -49,7 +50,7 @@ pub async fn get_xormapped_addr(
     conn: &Arc<dyn Conn + Send + Sync>,
     server_addr: SocketAddr,
     deadline: Duration,
-) -> Result<XorMappedAddress, Error> {
+) -> Result<XorMappedAddress> {
     let resp = stun_request(conn, server_addr, deadline).await?;
     let mut addr = XorMappedAddress::default();
     addr.get_from(&resp)?;
@@ -62,7 +63,7 @@ pub async fn stun_request(
     conn: &Arc<dyn Conn + Send + Sync>,
     server_addr: SocketAddr,
     deadline: Duration,
-) -> Result<Message, Error> {
+) -> Result<Message> {
     let mut request = Message::new();
     request.build(&[Box::new(BINDING_REQUEST), Box::new(TransactionId::new())])?;
 
@@ -72,9 +73,9 @@ pub async fn stun_request(
         match tokio::time::timeout(deadline, conn.recv_from(&mut bs)).await {
             Ok(result) => match result {
                 Ok((n, addr)) => (n, addr),
-                Err(err) => return Err(Error::new(err.to_string())),
+                Err(err) => return Err(Error::ErrOthers(err.to_string()).into()),
             },
-            Err(err) => return Err(Error::new(err.to_string())),
+            Err(err) => return Err(Error::ErrOthers(err.to_string()).into()),
         }
     } else {
         conn.recv_from(&mut bs).await?
@@ -130,14 +131,14 @@ pub async fn listen_udp_in_port_range(
     port_max: u16,
     port_min: u16,
     laddr: SocketAddr,
-) -> Result<Arc<dyn Conn + Send + Sync>, Error> {
+) -> Result<Arc<dyn Conn + Send + Sync>> {
     if laddr.port() != 0 || (port_min == 0 && port_max == 0) {
         return vnet.bind(laddr).await;
     }
     let i = if port_min == 0 { 1 } else { port_min };
     let j = if port_max == 0 { 0xFFFF } else { port_max };
     if i > j {
-        return Err(ERR_PORT.to_owned());
+        return Err(Error::ErrPort.into());
     }
 
     let port_start = rand::random::<u16>() % (j - i + 1) + i;
@@ -158,5 +159,5 @@ pub async fn listen_udp_in_port_range(
         }
     }
 
-    Err(ERR_PORT.to_owned())
+    Err(Error::ErrPort.into())
 }
